from .currency import Currency
from .distance import Distance
from .geocoding import Geocoding
from .weather import Weather


class Extra:
  def __init__(self, API_KEY):
    self.key = API_KEY

  def currency(self):
    return Currency(self.key)

  def distance(self):
    return Distance(self.key)

  def geocoding(self):
    return Geocoding(self.key)

  def weather(self):
    return Weather(self.key)



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Notifications:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self, params):
    return requests.get('{api_endpoint}/notification'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

  def markAsRead(self, notifications):
    if not isinstance(notifications, list):
      try:
        notifications = list(notifications)
      except TypeError:
        raise ValueError('Parameter should be iterable')
    else:
      data = {'notification_ids': notifications}
    return requests.put('{api_endpoint}/notification/read'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def accept(self, notification_id):
    return requests.post('{api_endpoint}/notification/accept/{notification_id}'.format(api_endpoint=API_TAGO, notification_id=notification_id), headers=self.default_headers).json()

  def refuse(self, notification_id):
    return requests.post('{api_endpoint}/notification/refuse/{notification_id}'.format(api_endpoint=API_TAGO, notification_id=notification_id), headers=self.default_headers).json()

  def remove(self, notification_id):
    return requests.delete('{api_endpoint}/notification/{notification_id}'.format(api_endpoint=API_TAGO, notification_id=notification_id), headers=self.default_headers).json()

  def registerDevice(self, device_token, platform):
    data = {
      'device_token': device_token,
      'platform': platform,
    }
    return requests.post('{api_endpoint}/notification/push/register'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def unregisterDevice(self, device_token):
    data = {
      'device_token': device_token,
    }
    return requests.post('{api_endpoint}/notification/push/unregister'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Template:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def generateTemplate(self, templateObj):
    return requests.post('{api_endpoint}/template'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(templateObj)).json()

  def installTemplate(self, template_id, data={}):
    return requests.post('{api_endpoint}/template/{template_id}'.format(api_endpoint=API_TAGO, template_id=template_id), headers=self.default_headers, data=json.dumps(data)).json()

  @staticmethod
  def staticGetTemplate(self, template_id):
    return requests.post('{api_endpoint}/template/{template_id}'.format(api_endpoint=API_TAGO, template_id=template_id), headers=self.default_headers).json()

  def getTemplate(self, template_id):
    return Template.staticGetTemplate(self, template_id)



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class PaymentMethods:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/account/payment_method'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def list(self):
    return requests.get('{api_endpoint}/account/payment_method'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def setDefaultPaymentMethod(self, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/account/payment_method'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def deletePaymentMethod(self, data):
    data = data if data else {}
    return requests.delete('{api_endpoint}/account/payment_method'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()



import requests  # Used to make HTTP requests
import os
import json

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'

def invite(type, ref_id, data, default_options):
  data = data if data else {}
  if ref_id is None or ref_id == '':
    raise ValueError('ref_id must be set')
  elif data['email'] is None or data['email'] == '':
    raise ValueError('email must be set in data')
  return requests.post('{api_endpoint}/share/{type}/{ref_id}'.format(api_endpoint=API_TAGO, type=type, ref_id=ref_id), headers=default_options, data=json.dumps(data)).json()

def edit(share_id, data, default_options):
  data = data if data else {}
  if share_id is None or share_id == '':
    raise ValueError('share_id must be set')
  return requests.put('{api_endpoint}/share/{share_id}'.format(api_endpoint=API_TAGO, share_id=share_id), headers=default_options, data=json.dumps(data)).json()

def list_share(type, ref_id, default_options):
  if ref_id is None or ref_id == '':
    raise ValueError('ref_id must be set')
  return requests.get('{api_endpoint}/share/{type}/{ref_id}'.format(api_endpoint=API_TAGO, type=type, ref_id=ref_id), headers=default_options).json()

def remove(share_id, default_options):
  if share_id is None or share_id == '':
    raise ValueError('share_id must be set')
  return requests.delete('{api_endpoint}/share/{share_id}'.format(api_endpoint=API_TAGO, share_id=share_id), headers=default_options).json()



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Notification:
  def __init__(self, analysis_token):
    self.token = analysis_token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': analysis_token}

  def send(self, title, message, ref_id):
    data = {
      'title': title,
      'message': message,
      'ref_id': ref_id
    }
    return requests.post('{api_endpoint}/analysis/services/notification/send'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()



import requests
import json
import os


class Distance:
  def __init__(self, key):
    self.key = key
    self.default_headers = {'Device-Token': key}

    #
    # Find distance between two locations
    # API Documentation : https://developers.google.com/maps/documentation/distance-matrix/intro
    # origin{string}
    # destination{string}
    # language{string}
    # mode{string}
    # example origin : '35.7706256,-78.6952835'
    # example destination : '35.7728213,-78.6865257'
    #

  def measure(self, origin, destination, language, mode):
    if not origin or not destination:
      raise ValueError("Empty or Bad arguments")

    if not mode:
      mode = 'car'

    if not language:
      language = 'en-US'

    url = 'https://maps.googleapis.com/maps/api/distancematrix/json'
    data = {'key': self.key, 'origins': origin, 'destinations': destination,
        'mode': mode, 'language': language}
    distance = requests.get(
      url, params=data, headers=self.default_headers).json()
    return distance



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'


class Email:
  def __init__(self, analysis_token):
    self.analysis_token = analysis_token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': analysis_token}

  # Send email
  # to{string} : email address to which the message is to be sent
  # subject{string} : Subject of the email
  # message{string} : Message of the email
  # s_from{string} : email to receive reply (optional)
  # attachment{json} : attachment to be sent
  # return promise

  def send(self, to, subject, message, s_from, attachment, html, whitelabel_url):
    if not to or not message or not subject:
      raise ValueError("Empty or Bad arguments")

    data = {'to': to, 'subject': subject, 'message': message,
        'from': s_from, 'attachment': attachment, 'html': html, 'whitelabel_url': whitelabel_url}
    url = '{api_endpoint}/analysis/services/email/send'.format(
      api_endpoint=API_TAGO)
    return requests.post(url, data=json.dumps(data), headers=self.default_headers).json()



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'


class Sms:
  def __init__(self, analysis_token):
    self.analysis_token = analysis_token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': analysis_token}

  # Send SMS to a number
  # to{string} : Number to send SMS, Example: +554498774411
  # message{string} :
  # Returns Promise
  def send(self, to, message):
    if not to or not message:
      raise ValueError("Empty or Bad arguments")

    data = {'to': to, 'message': message}
    url = '{api_endpoint}/analysis/services/sms/send'.format(
      api_endpoint=API_TAGO)
    return requests.post(url, data=json.dumps(data), headers=self.default_headers).json()



from socketIO_client import SocketIO, LoggingNamespace
# import logging
# logging.getLogger('socketIO-client').setLevel(logging.DEBUG)
# logging.basicConfig()


class TagoRealTime:
  def __init__(self, address, token, callback):
    self.socket = SocketIO(address, 443, LoggingNamespace)
    self.token = token
    self.callback = callback

  def on_connect(self):
    self.socket.emit('register', self.token)

  def listening(self, channel, wait):
    self.socket.on('connect', self.on_connect)
    self.socket.on(channel, self.callback)

    if wait:
      self.socket.wait(seconds=wait)
    else:
      self.socket.wait()

    return self.socket

  def stopListening(self, channel):
    self.socket.off(channel)



from .emailService import Email
from .sms import Sms
from .console import Console
from .mqtt import Mqtt
from .attachment import Attachment
from .notification import Notification


class Services:
  def __init__(self, token):
    self.token = token

  def sms(self):
    return Sms(self.token)

  def email(self):
    return Email(self.token)

  def console(self):
    return Console(self.token)

  def MQTT(self):
    return Mqtt(self.token)

  def notification(self):
    return Notification(self.token)

  def attachment(self):
    return Attachment(self.token)



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Actions:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self, page=1, fields=['id', 'name'], filter={}, amount=20, orderBy='name,asc'):
    params = {
      'page': page,
      'fields': fields,
      'filter': filter,
      'amount': amount,
      'orderBy': orderBy,
    }
    return requests.get('{api_endpoint}/action'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(params)).json()

  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/action'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def edit(self, action_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/action/{action_id}'.format(api_endpoint=API_TAGO, action_id=action_id), headers=self.default_headers, data=json.dumps(data)).json()

  def delete(self, action_id):
    return requests.delete('{api_endpoint}/action/{action_id}'.format(api_endpoint=API_TAGO, action_id=action_id), headers=self.default_headers).json()

  def info(self, action_id):
    if action_id is None or action_id == '':
      return self.list()
    return requests.get('{api_endpoint}/action/{action_id}'.format(api_endpoint=API_TAGO, action_id=action_id), headers=self.default_headers).json()



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Devices:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self, page=1, fields=['id', 'name'], filter={}, amount=20, orderBy='name,asc', resolveBucketName=False):
    params = {
      'page': page,
      'filter': filter,
      'fields': fields,
      'amount': amount,
      'orderBy': orderBy,
      'resolveBucketName': resolveBucketName
    }
    return requests.get('{api_endpoint}/device'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/device'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def edit(self, device_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/device/{device_id}'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers, data=json.dumps(data)).json()

  def delete(self, device_id):
    return requests.delete('{api_endpoint}/device/{device_id}'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers).json()


  def tokenList(self, device_id, page=1, amount=20, filter={}, fields=['name', 'token', 'permission'], orderBy='created_at,desc', resolveBucketName=False):
    params = {
      'page': page,
      'filter': filter,
      'amount': amount,
      'orderBy': orderBy,
      'fields': fields,
    }
    return requests.get('{api_endpoint}/device/token/{device_id}'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers, params=json.dumps(params)).json()

  def tokenCreate(self, device_id, data):
    data = data if data else {}
    data['device'] = device_id

    return requests.post('{api_endpoint}/device/token'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def tokenDelete(self, token_id):
    return requests.delete('{api_endpoint}/device/token/{token_id}'.format(api_endpoint=API_TAGO, token_id=token_id), headers=self.default_headers).json()

  def info(self, device_id):
    # if device id is null, then call list
    if device_id is None or device_id == '':
      return self.list()

    return requests.get('{api_endpoint}/device/{device_id}'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers).json()

  def paramSet(self, device_id, data):
    return requests.post('{api_endpoint}/device/{device_id}/params'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers, data=json.dumps(data)).json()

  def paramCreate(self, device_id, data):
    return requests.post('{api_endpoint}/device/{device_id}/params'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers, data=json.dumps(data)).json()

  def paramEdit(self, device_id, param_id, data):
    return requests.put('{api_endpoint}/device/{device_id}/params/{param_id}'.format(api_endpoint=API_TAGO, device_id=device_id, param_id=param_id), headers=self.default_headers, data=json.dumps(data)).json()

  def paramList(self, device_id, sent_status):
    params = {
      'sent_status': sent_status,
    }
    return requests.get('{api_endpoint}/device/{device_id}/params'.format(api_endpoint=API_TAGO, device_id=device_id), headers=self.default_headers, params=json.dumps(params)).json()

  def paramRemove(self, device_id, param_id):
    return requests.delete('{api_endpoint}/device/{device_id}/params/{param_id}'.format(api_endpoint=API_TAGO, device_id=device_id, param_id=param_id), headers=self.default_headers).json()



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Authorization:
  def __init__(self, token):
    self.token = token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': token}

  def info(self):
    return requests.get('{api_endpoint}/info'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def createDevice(self, data):
    return requests.post('{api_endpoint}/device'.format(api_endpoint=API_TAGO), data=json.dumps(data), headers=self.default_headers).json()



import requests # Used to make HTTP requests
import json # Used to parse JSON
import os # Used to infer environment variables

from.actions import Actions
from.analysis import Analysis
from.files import Files
from.buckets import Buckets
from.dashboards import Dashboards
from.devices import Devices
from.notifications import Notifications
from.middlewares import Middlewares
from.tags import Tags
from.paymentMethods import PaymentMethods
from.plan import Plan
from.paymentHistory import PaymentHistory
from.explore import Explore
from.connector import Connector
from.template import Template
from.accessManagement import AccessManagement
from.run import TagoIORUN
from.profiles import Profiles
from.service_authorization import ServiceAuth

API_TAGO=os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME=os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'

class Account:
  def __init__(self, token):
    self.token=token
    self.default_headers={
      'content-type': 'application/json',
      'Account-Token': token
}

def info(self):
  return requests.get('{api_endpoint}/account'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

def summary(self, params=None):
  return requests.get('{api_endpoint}/account/summary'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

def statistics(self, params):
  return requests.get('{api_endpoint}/statistics'.format(api_endpoint=API_TAGO), params=params, headers=self.default_headers).json()

def edit(self, data):
  return requests.put('{api_endpoint}/account'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

def delete(self):
  return requests.delete('{api_endpoint}/account'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

def profileList(self):
  return requests.get('{api_endpoint}/account/profile'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

def profileCreate(self, data):
  return requests.post('{api_endpoint}/account/profile'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

def profileDelete(self, profile_id):
  return requests.delete('{api_endpoint}/account/profile/{profile_id}'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers).json()

def tokenList(self, page=1, amount=20, filter={}, fields=['name', 'token', 'permission'], orderBy='created_at,desc'):
  params={
    'page': page,
    'filter': filter,
    'amount': amount,
    'orderBy': orderBy,
    'fields': fields,
  }
  return requests.get('{api_endpoint}/account/profile/token'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(params)).json()

def tokenCreate(self, data):
  return requests.post('{api_endpoint}/account/profile/token'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

def tokenDelete(self):
  return requests.delete('{api_endpoint}/account/profile/token'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

def login(self, data):
  return requests.post('{api_endpoint}/account/profile/login'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

def passwordRecover(self, email):
  return requests.get('{api_endpoint}/account/passwordreset/{email}'.format(api_endpoint=API_TAGO, email=email), headers=self.default_headers).json()

def passwordChange(self, password):
  return requests.post('{api_endpoint}/account/passwordreset'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(password)).json()

def create(self, name, email, password, cpassword, country, timezone, company, newsletter, developer):
  params={
    'name': name,
    'email': email,
    'password': password,
    'cpassword': cpassword,
    'country': country,
    'timezone': timezone,
    'company': company,
    'newsletter': newsletter,
    'developer': developer,
  }
  return requests.post('{api_endpoint}/account'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(params)).json()

@staticmethod
def resendConfirmation(self, email):
  return requests.get('{api_endpoint}/account/resend_confirmation/{email}'.format(api_endpoint=API_TAGO, email=email), headers=self.default_headers).json()

def confirmAction(self, token):
  return requests.get('{api_endpoint}/account/confirm/{token}'.format(api_endpoint=API_TAGO, token=token), headers=self.default_headers).json()


def getActions(self):
  return Actions(self.token)

def getAnalysis(self):
  return Analysis(self.token)

def getBuckets(self):
  return Buckets(self.token)

def getFiles(self):
  return Files(self.token)

def getDashboards(self):
  return Dashboards(self.token)

def getDevices(self):
  return Devices(self.token)

def getNotifications(self):
  return Notifications(self.token)

def getMiddlewares(self):
  return Middlewares(self.token)

def getTags(self):
  return Tags(self.token)

def getPaymentMethods(self):
  return PaymentMethods(self.token)

def getPlan(self):
  return Plan(self.token)

def getPaymentHistory(self):
  return PaymentHistory(self.token)

def getExplore(self):
  return Explore(self.token)

def getConnector(self):
  return Connector(self.token)

def getTemplate(self):
  return Template(self.token)

def getAccessManagement(self):
  return AccessManagement(self.token)

def getRun(self):
  return TagoIORUN(self.token)

def getServiceAuthorization(self):
  return ServiceAuth(self.token)

def getProfiles(self):
  return Profiles(self.token)



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class ServiceAuth:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def tokenList(self, page=1, amount=20, filter={}, fields=['name', 'token', 'created_at'], orderBy='created_at,desc'):
    params = {
      'page': page,
      'filter': filter,
      'amount': amount,
      'orderBy': orderBy,
      'fields': fields,
    }
    return requests.get('{api_endpoint}/serviceauth'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

  def tokenCreate(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/serviceauth'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def tokenDelete(self, token):
    return requests.delete('{api_endpoint}/serviceauth/{token}'.format(api_endpoint=API_TAGO, token=token), headers=self.default_headers).json()

  def tokenEdit(self, token, verification_code):
    data = {'verification_code': verification_code}
    return requests.put('{api_endpoint}/serviceauth/{token}'.format(api_endpoint=API_TAGO, token=token), headers=self.default_headers, data=json.dumps(data)).json()



from ..services import Services
import os

REALTIME_URL = os.environ.get('TAGO_REALTIME') or 'wss://realtime.tago.io'
TAGO_RUNTIME = os.environ.get('TAGO_RUNTIME') or False

if TAGO_RUNTIME == False:
  import socketio
  import asyncio
  loop = asyncio.new_event_loop()
  asyncio.set_event_loop(loop)

class Analysis:
  def __init__(self, token):
    self._token = token

  def init(self, analysis):
    self._analysis = analysis
    if TAGO_RUNTIME is False:
      self.__localRuntime()
    else:
      return self.run

  def run(self, environment, data, analysis_id, token):
    def log(*args):
      print(*args)
      Services(token).console().log(str(args)[1:][:-2])

    def context():
      pass

    setattr(context, 'log', log)
    setattr(context, 'token', token)
    setattr(context, 'environment', environment)
    setattr(context, 'analysis_id', analysis_id)

    self._analysis(context, data or [])

  def __localRuntime(self):
    # logger=True, engineio_logger=True) #(reconnection=True, reconnection_delay=10000)
    sio = socketio.AsyncClient(reconnection=True, reconnection_delay=10000)

    async def connectSocket():
      def ready(analysisObj):
        print('Analysis [{AnalysisName}] Started\n'.format(AnalysisName=analysisObj['name']))

      def connect():
        print('Connected to TagoIO.')

      def disconnect():
        print('Disconnected from TagoIO.\n\n')

      def error(e):
        print('Connection error', e)

      def analysisTrigger(scope):
        self.run(scope['environment'], scope['data'], scope['analysis_id'], scope['token'])

      sio.on('ready', ready)
      sio.on('error', error)
      sio.on('connect', connect)
      sio.on('disconnect', disconnect)
      sio.on('analysis::trigger', analysisTrigger)

      await sio.connect(url=REALTIME_URL + '?token=' + self._token, transports=['websocket'])
      await sio.wait()

    loop.run_until_complete(connectSocket())



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables
from ._share import * # Used in share methods

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'


class Buckets:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self, page=1, fields=['id', 'name'], filter={}, amount=20, orderBy='name,asc'):
    params = {
      'page': page,
      'fields': fields,
      'filter': filter,
      'amount': amount,
      'orderBy': orderBy,
    }
    return requests.get('{api_endpoint}/bucket'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(params)).json()

  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/bucket'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def edit(self, bkt_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/bucket/{bkt_id}'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers, data=json.dumps(data)).json()

  def delete(self, bkt_id):
    return requests.delete('{api_endpoint}/bucket/{bkt_id}'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers).json()

  def deleteVariable(self, bkt_id, data):
    data = data if data else {}
    return requests.delete('{api_endpoint}/bucket/{bkt_id}/variable'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers, data=json.dumps(data)).json()

  def listVariables(self, bkt_id, show_amount=False, show_deleted=False, resolveOriginName=False):
    params = {
      'amount': show_amount,
      'deleted': show_deleted,
      'resolveOriginName': resolveOriginName,
    }
    return requests.get('{api_endpoint}/bucket/{bkt_id}/variable'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers, params=json.dumps(params)).json()

  def getDevicesAssociated(self, bkt_id):
    if bkt_id is None or bkt_id == '':
      raise ValueError('Bucket ID parameter is obrigatory.')
    return requests.get('{api_endpoint}/bucket/{bkt_id}/device'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers).json()

  def amount(self, bkt_id):
    if bkt_id is None or bkt_id == '':
      raise ValueError('Bucket ID parameter is obrigatory.')
    return requests.get('{api_endpoint}/bucket/{bkt_id}/data_amount'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers).json()

  def info(self, bkt_id):
    # if bkt_id is null, then call list
    if bkt_id is None or bkt_id == '':
      return self.list()

    return requests.get('{api_endpoint}/bucket/{bkt_id}'.format(api_endpoint=API_TAGO, bkt_id=bkt_id), headers=self.default_headers).json()

  def backupInfo(self, backup_id):
    # if backup_id is null, then error!
    if backup_id is None or backup_id == '':
      raise ValueError('backup_id must be set')

    return requests.get('{api_endpoint}/backup/{backup_id}'.format(api_endpoint=API_TAGO, backup_id=backup_id), headers=self.default_headers).json()

  def backupList(self):
    return requests.get('{api_endpoint}/backup'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def backupDelete(self, backup_id):
    # if bkt_id is null, then error!
    if backup_id is None or backup_id == '':
      raise ValueError('backup_id must be set')

    return requests.delete('{api_endpoint}/backup/{backup_id}'.format(api_endpoint=API_TAGO, backup_id=backup_id), headers=self.default_headers).json()

  def backupRecover(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/backup/recover'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def shareList(self, bucket_id):
    # if bucket_id is null, then ERROR
    if bucket_id is None or bucket_id == '':
      raise ValueError('bucket_id must be set')

    return list_share('bucket', bucket_id, self.default_headers)

  def shareSendInvite(self, bucket_id, data):
    data = data if data else {}

    # if bucket_id is null, then ERROR
    if bucket_id is None or bucket_id == '':
      raise ValueError('bucket ID must be set')

    if data['email'] is None or data['email'] == '':
      raise ValueError('email must be set')

    return invite('bucket', bucket_id, data, self.default_headers)

  def shareEdit(self, share_id, data):
    data = data if data else {}

    # if share_id is null, then ERROR
    if share_id is None or share_id == '':
      raise ValueError('share_id must be set')

    if data['email'] is None or data['email'] == '':
      raise ValueError('email must be set')

    return edit(share_id, data, self.default_headers)

  def shareDelete(self, share_id):
    # if share_id is null, then ERROR
    if share_id is None or share_id == '':
      raise ValueError('share_id must be set')

    return remove(share_id, self.default_headers)

  def exportData(self, output, buckets, options):
    if output is None or output == '':
      raise ValueError('output must be set')
    elif buckets is None or buckets[0] is None:
      raise ValueError('bucket must be set')

    data = {}
    data['buckets'] = buckets
    data['start_date'] = options['start_date']
    data['end_date'] = options['end_date']

    return requests.post('{api_endpoint}/data/export?output={output}'.format(api_endpoint=API_TAGO, output=output), headers=self.default_headers, data=json.dumps(data)).json()



from .device import Device
from .analysis import Analysis
from .account import Account
from .services import Services
from .extra import Extra
from .connector import Connector
from .authorization import Authorization
from .run_user import RunUser

class Tago:
  def __init__(self, token):
    self.account = Account(token)
    self.analysis = Analysis(token)
    self.authorization = Authorization(token)
    self.connector = Connector(token)
    self.device = Device(token)
    self.extra = Extra(token)
    self.run_user = RunUser(token)
    self.services = Services(token)



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class RunUser:
  def __init__(self, token):
    self.token = token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': token}

  def info(self, tagoRunURL):
    return requests.get('{api_endpoint}/run/{tagoRunURL}/info'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers).json()

  def editInfo(self, tagoRunURL, changes={}):
    data = changes
    return requests.put('{api_endpoint}/run/{tagoRunURL}/info'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers, data=json.dumps(data)).json()

  @staticmethod
  def create(self, tagoRunURL, newUserObj):
    return requests.post('{api_endpoint}/run/{tagoRunURL}/signup'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers, data=json.dumps(newUserObj)).json()

  # email and password should be in a object?
  @staticmethod
  def login(self, tagoRunURL, emailAndPasswordObject):
    data = {
      'email': emailAndPasswordObject.email,
      'password': emailAndPasswordObject.password
    }
    return requests.post('{api_endpoint}/run/{tagoRunURL}/login'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers, data=json.dumps(data)).json()

  @staticmethod
  def confirmUser(self, tagoRunURL, token):
    return requests.get('{api_endpoint}/run/{tagoRunURL}/confirm/{token}'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL, token=token), headers=self.default_headers).json()

  @staticmethod
  def passwordRecover(self, tagoRunURL, email):
    return requests.get('{api_endpoint}/run/{tagoRunURL}/passwordreset/{email}'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL, email=email), headers=self.default_headers).json()

  @staticmethod
  def passwordChange(self, tagoRunURL, password):
    return requests.post('{api_endpoint}/run/{tagoRunURL}/passwordreset/{email}'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), data=json.dumps(password), headers=self.default_headers).json()

  def notificationList(self, tagoRunURL):
    return requests.get('{api_endpoint}/run/{tagoRunURL}/notification'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers).json()

  def notificationMarkRead(self, tagoRunURL, notifications):
    if not isinstance(notifications, list):
      raise ValueError('Notifications parameter must be a list')
    data = {'notification_ids': notifications}
    return requests.put('{api_endpoint}/run/{tagoRunURL}/notification'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL), headers=self.default_headers, data=json.dumps(data)).json()

  def notificationButton(self, tagoRunURL, notification_id, btn_id):
    return requests.put('{api_endpoint}/run/{tagoRunURL}/notification/{notification_id}/{btn_id}'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL, notification_id=notification_id, btn_id=btn_id), headers=self.default_headers).json()

  def notificationDelete(self, tagoRunURL, notification_id):
    return requests.delete('{api_endpoint}/run/{tagoRunURL}/notification/{notification_id}'.format(api_endpoint=API_TAGO, tagoRunURL=tagoRunURL, notification_id=notification_id), headers=self.default_headers).json()



import requests
import json
import os


class Geocoding:
  def __init__(self, key):
    self.key = key
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': key}

  def getAddress(self, geolocation):
    if type(geolocation) == str:
      geoplited = geolocation.split(',')

      if len(geoplited) > 1:
        geolocation = [geoplited[0].strip(), geoplited[1].strip()]
      else:
        raise ValueError("Invalid geolocation")
    elif geolocation.coordinates:
      geolocation = geolocation.coordinates
    else:
      raise ValueError("Invalid geolocation")

    geolocation = ','.join([geolocation[0], geolocation[1]])

    url = 'https://maps.googleapis.com/maps/api/geocode/json'
    query = {'latlng': geolocation, 'key': self.key}
    geoloc_response = requests.get(
      url, params=query, headers=self.default_headers).json()
    return geoloc_response

  def getGeolocation(self, address):
    url = 'https://maps.googleapis.com/maps/api/geocode/json'
    query = {'address': address, 'key': self.key}
    geoloc_response = requests.get(
      url, params=query, headers=self.default_headers).json()
    return geoloc_response



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class TagoIORUN:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def edit(self, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/run'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def info(self):
    return requests.get('{api_endpoint}/run'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def listUsers(self, page=1, fields=['id', 'name'], filter={}, amount=20, orderBy='name,asc'):
    params = {
      'page': page,
      'filter': filter,
      'fields': fields,
      'amount': amount,
      'orderBy': orderBy,
    }
    return requests.get('{api_endpoint}/run/users'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

  def getUserInfo(self, userID):
    return requests.get('{api_endpoint}/run/users/{userID}'.format(api_endpoint=API_TAGO, userID=userID), headers=self.default_headers).json()

  def loginAsUser(self, userID):
    return requests.get('{api_endpoint}/run/users/{userID}/login'.format(api_endpoint=API_TAGO, userID=userID), headers=self.default_headers).json()

  def userEdit(self, userID, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/run/users/{userID}'.format(api_endpoint=API_TAGO, userID=userID), headers=self.default_headers, data=json.dumps(data)).json()

  def createUser(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/run/users'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def deleteUser(self, userID):
    return requests.delete('{api_endpoint}/run/users/{userID}'.format(api_endpoint=API_TAGO, userID=userID), headers=self.default_headers).json()

  def emailTest(self, dataObj):
    data = {
      'subject': dataObj.subject,
      'body': dataObj.body
    }
    return requests.post('{api_endpoint}/run/email_test'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def notificationCreate(self, user_id, data):
    data = data if data else {}
    data['run_user'] = user_id
    return requests.post('{api_endpoint}/run/notification'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def notificationEdit(self, notification_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/run/notification/{notification_id}'.format(api_endpoint=API_TAGO, notification_id=notification_id), headers=self.default_headers, data=json.dumps(data)).json()

  def notificationDelete(self, notification_id):
    return requests.delete('{api_endpoint}/run/notification/{notification_id}'.format(api_endpoint=API_TAGO, notification_id=notification_id), headers=self.default_headers).json()

  def notificationList(self, user_id):
    return requests.get('{api_endpoint}/run/notification/{user_id}'.format(api_endpoint=API_TAGO, user_id=user_id), headers=self.default_headers).json()



# *-* coding:utf-8 *-*

import setuptools

with open('README.md', 'r') as f:
  long_description = f.read()

with open('requirements.txt', 'r') as f:
  required = f.read().splitlines()

setuptools.setup(
  name='tago',
  version='3.0.3',
  python_requires='>=3.6',
  description='Official Python lib for TagoIO',
  long_description=long_description,
  long_description_content_type="text/markdown",
  classifiers=[
      'Development Status :: 5 - Production/Stable',
      'License :: OSI Approved :: Apache Software License',
      'Programming Language :: Python :: 3 :: Only',
      'Topic :: Software Development :: Libraries :: Python Modules',
  ],
  keywords='tago tagoio develop iot sdk analysis device',
  url='https://github.com/tago-io/tago-sdk-python',
  author='Tago LLC',
  author_email='dev@tago.io',
  license='Apache License',
  packages=setuptools.find_packages(),
  install_requires=required,
  zip_safe=False
)



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'


class Widgets:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

    # Create a Dashboard Widget
    # @param  {String} dashboard id
    # @param  {JSON} data
    # @return {Promise}
  def create(self, dash_id, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/dashboard/{dash_id}/widget/'.format(api_endpoint=API_TAGO, dash_id=dash_id), headers=self.default_headers, data=json.dumps(data)).json()

    # Edit the Dashboard Widget
    # @param  {String} dashboard id
    # @param  {String} widget id
    # @param  {Object} data
    # @return {Promise}
  def edit(self, dash_id, widget_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/dashboard/{dash_id}/widget/{widget_id}'.format(api_endpoint=API_TAGO, dash_id=dash_id, widget_id=widget_id), headers=self.default_headers, data=json.dumps(data)).json()

    # Delete the Dashboard Widget
    # @param  {String} dashboard id
    # @param  {String} widget id
    # @return {Promise}
  def delete(self, dash_id, widget_id):
    return requests.delete('{api_endpoint}/dashboard/{dash_id}/widget/{widget_id}'.format(api_endpoint=API_TAGO, dash_id=dash_id, widget_id=widget_id), headers=self.default_headers).json()

    # Get Info of the Dashboard Widget
    # @param  {String} dashboard id
    # @param  {String} widget id
    # @return {Promise}
    # def info(self, dash_id, widget_id):
    # 	# if widget_id is null, then call list
    # 	if widget_id is None or widget_id == '':
    #     return self.list()

    # 	return requests.get('{api_endpoint}/dashboard/{dash_id}/widget/{widget_id}'.format(api_endpoint=API_TAGO, dash_id=dash_id, widget_id=widget_id), headers=self.default_headers).json()

    # Get all data for the current widget
    # @param  {String} dashboard id
    # @param  {String} widget id
    # @return {Promise}
  def getData(self, dashboard_id, widget_id, overwrite={}):
    params = {
      'overwrite': overwrite,
    }
    return requests.get('{api_endpoint}/data/{dashboard_id}/{widget_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id, widget_id=widget_id), headers=self.default_headers, params=json.dumps(params)).json()

    # Update value of variable for the current widget
    # @param  {String} dashboard id
    # @param  {String} widget_id
    # @param  {JSON} data
    # @return {Promise}
  def sendData(self, dashboard_id, widget_id, data, bypassBucket):
    data = data if data else {}
    params = {
      'bypass_bucket': bypassBucket or False,
    }
    return requests.post('{api_endpoint}/data/{dashboard_id}/{widget_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id, widget_id=widget_id), headers=self.default_headers, data=json.dumps(data), params=json.dumps(params)).json()

  def runAnalysis(self, dashboard_id, widget_id, data):
    return requests.post('{api_endpoint}/data/{dashboard_id}/{widget_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id, widget_id=widget_id), headers=self.default_headers, data=json.dumps(data)).json()

  def deleteData(self, dashboard_id, widget_id, ids):
    params = {
      'ids': ids,
    }
    return requests.delete('{api_endpoint}/data/{dashboard_id}/{widget_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id, widget_id=widget_id), headers=self.default_headers, params=json.dumps(params)).json()

  def tokenGenerate(self, dashboard_id, widget_id):
    return requests.get('{api_endpoint}/dashboard/{dashboard_id}/widget/{widget_id}/token'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id, widget_id=widget_id), headers=self.default_headers).json()



from promise import Promise
import requests


def service_request(request_options):
  result = requests.get(request_options['url'], request_options['params'])
  if result.status_code != 200:
    return Promise.reject('Error on Third-Party service')
  body = result.text
  try:
    body = JSON.parse(body)
  except:
    pass
  if result.status_code != requests.codes.ok:
    console.error(body)
    return Promise.reject('Error on Third-Party service')
  return Promise.resolve(body)



import json


def default_headers(class_context):
  class_context = class_context or type('', (), {})()
  headers = {}
  if hasattr(class_context, 'token'):
    headers['Token'] = class_context.token
  return json.dumps(headers)



from promise import Promise
from .service_request import service_request as request
from .default_headers import default_headers
from datetime import datetime
import urllib
import ast

# Wunderground docs: http://www.wunderground.com/weather/api/d/docs


class Weather:
  def __init__(self, key):
    self.key = key
    self.default_options = {'json': True, 'headers': default_headers(self)}

  def _setParams(self, params):
    self._query = params['query'] or None
    self._full = params['full'] or False
    self._lang = params['lang'] or 'EN'

  def geolocation_verify(geolocation):
    if type(geolocation) == 'string':
      geoplited = geolocation.split(',')
      if geolocation.length > 1:
        geolocation = [geoplited[0].strip(), geoplited[1].strip()]
      else:
        return None
    elif geolocation.coordinates:
      geolocation = geolocation.coordinates
    else:
      return None
    return ','.join([geolocation[0], geolocation[1]])

  def current(self, query, full, lang):
    def current_result(result):
      result = ast.literal_eval(result)
      if 'results' in result['response']:
        if 'current_observation' not in result:
          return Promise.reject('Invalid address, ' + str(len(result['response']['results'])) + ' match.')
      elif 'current_observation' not in result:
        return Promise.reject('Invalid address')
      result = result['current_observation']
      try:
        del result['image']
        del result['icon_url']
        del result['forecast_url']
        del result['history_url']
        del result['ob_url']
        del result['estimated']
      except Exception as e:
        return Promise.reject('weather system, ' + str(e))
      return Promise.resolve(result)

    params = {'query': query, 'full': full, 'lang': lang, 'key': self.key}
    self._setParams(params)
    url = 'http://api.wunderground.com/api/'+self.key+'/lang:'+self._lang + \
      '/conditions/q/'+urllib.quote(self._query.encode("utf-8"))+'.json'
    method = 'GET'

    self.default_options['url'] = url
    self.default_options['method'] = method
    self.default_options['params'] = params
    options = self.default_options
    return request(options).then(lambda result: current_result(result))

  def history(self, date, query, full, lang):
    def history_result(result):
      result = ast.literal_eval(result)
      result = result['history']
      return Promise.resolve(result)

    params = {'query': query, 'full': full, 'lang': lang}
    self._setParams(params)
    try:
      date = datetime.strptime(date, '%Y-%m-%d')
      date = str(date.year) + str(format(date.month, '02')) + \
        str(format(date.day, '02'))
    except Exception as e:
      return Promise.reject('Invalid date', + e)
    url = 'http://api.wunderground.com/api/'+self.key+'/lang:'+self._lang + \
      '/history_'+str(date)+'/q/' + \
      urllib.quote(self._query.encode("utf-8"))+'.json'
    method = 'GET'
    self.default_options['url'] = url
    self.default_options['method'] = method
    self.default_options['params'] = params
    options = self.default_options
    return request(options).then(lambda result: history_result(result))

  def forecast(self, query, full, lang):
    def forecast_result(result):
      result = ast.literal_eval(result)
      print(result)
      try:
        result = result['forecast']
      except Exception as e:
        return Promise.reject('Error on parse weather forecast ' + str(e))
      return Promise.resolve(result)

    params = {'query': query, 'full': full, 'lang': lang, 'key': self.key}
    self._setParams(params)
    url = 'http://api.wunderground.com/api/' + self.key + \
      '/forecast/q/'+urllib.quote(self._query.encode("utf-8"))+'.json'
    method = 'GET'
    self.default_options['url'] = url
    self.default_options['method'] = method
    self.default_options['params'] = params
    options = self.default_options
    return request(options).then(lambda result: forecast_result(result))

  def alerts(self, query, full, lang):
    def alerts_result(result):
      result = ast.literal_eval(result)
      del result['response']
      return Promise.resolve(result)

    params = {'query': query, 'full': full, 'lang': lang}
    self._setParams(params)
    url = 'http://api.wunderground.com/api/'+self.key+'/alerts/q/' + \
      urllib.quote(self._query.encode("utf-8"))+'.json'
    method = 'GET'
    self.default_options['url'] = url
    self.default_options['method'] = method
    self.default_options['params'] = params
    options = self.default_options
    return request(options).then(lambda result: alerts_result(result))



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Device:
  def __init__(self, token):
    self.token = token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': token}

  def info(self):
    return requests.get('{api_endpoint}/info'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def insert(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/data'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def find(self, query_obj):
    query_obj = query_obj if query_obj else {}
    return requests.get('{api_endpoint}/data'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(query_obj)).json()

  def remove(self, args={}):
    queryOrID = args.get('queryOrID')
    if not args:
      queryOrID = {
        'query': 'last_item'
      }
    query_obj = queryOrID if queryOrID else {}
    return requests.delete('{api_endpoint}/data'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(query_obj)).json()

  def getParams(self, sent_status):
    return requests.get('{api_endpoint}/device/params'.format(api_endpoint=API_TAGO), params=json.dumps(sent_status), headers=self.default_headers).json()

  def markParam(self, param_id):
    return requests.put('{api_endpoint}/device/params/{param_id}'.format(api_endpoint=API_TAGO, param_id=param_id), headers=self.default_headers).json()



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Files:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self, path='/', pagination_token=None, qty=300):
    params = {
      'path': path,
      'pagination_token': pagination_token,
      'qty': qty,
    }
    return requests.get('{api_endpoint}/files/'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(params)).json()

  def uploadBase64(self, arrayOfFileObjects):
    return requests.post('{api_endpoint}/files'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(arrayOfFileObjects)).json()

  def move(self, arrayOfFileObjects):
    return requests.put('{api_endpoint}/files'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(arrayOfFileObjects)).json()

  def delete(self, arrayOfFileObjects):
    return requests.delete('{api_endpoint}/files'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(arrayOfFileObjects)).json()

  def checkPermission(self, file):
    return requests.get('{api_endpoint}/files/permission'.format(api_endpoint=API_TAGO), headers=self.default_headers, params=json.dumps(file)).json()

  def changePermission(self, arrayOfFileObjects):
    return requests.put('{api_endpoint}/files/permission'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(arrayOfFileObjects)).json()

  def getFileURLSigned(self, url):
    if '.tago.io/file/' not in url:
      raise ValueError('{url} is not a TagoIO files url'.format(url=url))
    return requests.get(url=url, headers=self.default_headers, params=json.dumps({'noRedirect': True})).json()



import time
import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'

class Console:
  def __init__(self, analysis_token):
    self.analysis_token = analysis_token
    self.default_headers = { 'content-type': 'application/json', 'Device-Token': analysis_token}

  def log(self, message, timestamp = None):
    if not message:
      raise ValueError("Empty or Bad arguments")

    if not timestamp:
      timestamp = time.time() * 1000  # Time from epoch in sec*1000

    data = {'message': message, 'timestamp': timestamp}
    url = '{api_endpoint}/analysis/services/console/send'.format(api_endpoint=API_TAGO)
    return requests.post(url, data=json.dumps(data), headers=self.default_headers).json()



import requests
import json
import os

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Attachment:
  def __init__(self, analysis_token):
    self.token = analysis_token
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': analysis_token}

  # TODO: test it
  def upload(self, archive, filename, type):
    data = {
      'archive': archive,
      'filename': filename,
      'type': type,
    }
    return requests.post('{api_endpoint}/analysis/services/attachment/upload'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()



import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Profiles:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}
    return

  def list(self):
    return requests.get('{api_endpoint}/profile'.format(api_endpoint=API_TAGO), headers=self.default_headers).json()

  def info(self, profile_id):
    if profile_id is None or profile_id == '':
      raise ValueError('Profile ID parameter is obrigatory.')
    return requests.get('{api_endpoint}/profile/{profile_id}'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers).json()

  def edit(self, profile_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/profile/{profile_id}'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, data=json.dumps(data)).json()

  def delete(self, profile_id):
    return requests.delete('{api_endpoint}/profile/{profile_id}'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers).json()

  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/profile'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

  def usageStatisticList(self, profile_id, date, timezone):
    params = {
      'date': date,
      'timezone': timezone
    }
    return requests.get('{api_endpoint}/profile/{profile_id}/statistics'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, params=json.dumps(params)).json()

  def tokenList(self, profile_id, page=1, amount=20, filter={}, fields=['name', 'token', 'created_at'], orderBy='created_at,desc'):
    params = {
      'page': page,
      'filter': filter,
      'amount': amount,
      'orderBy': orderBy,
      'fields': fields
    }
    return requests.get('{api_endpoint}/profile/{profile_id}/token'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, params=json.dumps(params)).json()

  def shareList(self, profile_id):
    return requests.get('{api_endpoint}/profile/{profile_id}/share'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers).json()

  def shareCreate(self, profile_id, email):
    data = {'email': email}
    return requests.get('{api_endpoint}/profile/{profile_id}/share'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, data=json.dumps(data)).json()

  def shareDelete(self, profile_id, share_id):
    return requests.delete('{api_endpoint}/profile/{profile_id}/share/{share_id}'.format(api_endpoint=API_TAGO, profile_id=profile_id, share_id=share_id), headers=self.default_headers).json()

  def tokenCreate(self, profile_id, data):
    data = data if data else {}
    data['profile_id'] = profile_id
    return requests.post('{api_endpoint}/profile/{profile_id}/token'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, data=json.dumps(data)).json()

  def tokenDelete(self, profile_id, token):
    return requests.delete('{api_endpoint}/profile/{profile_id}/token/{token}'.format(api_endpoint=API_TAGO, profile_id=profile_id, token=token), headers=self.default_headers).json()

  def addonList(self, profile_id):
    return requests.get('{api_endpoint}/profile/{profile_id}/addons'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers).json()

  def addonEdit(self, profile_id, data):
    return requests.post('{api_endpoint}/profile/{profile_id}/addons'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, data=json.dumps(data)).json()

  def serviceEdit(self, profile_id, data):
    return requests.post('{api_endpoint}/profile/{profile_id}/services'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, data=json.dumps(data)).json()

  def transferTokenToAnotherProfile(self, target_profile_id):
    return requests.put('{api_endpoint}/profile/switch/{target_profile_id}'.format(api_endpoint=API_TAGO, target_profile_id=target_profile_id), headers=self.default_headers).json()

  def summary(self, profile_id, params):
    return requests.get('{api_endpoint}/profile/{profile_id}/summary'.format(api_endpoint=API_TAGO, profile_id=profile_id), headers=self.default_headers, params=json.dumps(params)).json()




import requests  # Used to make HTTP requests
import json  # Used to parse JSON
import os  # Used to infer environment variables
from ._share import *
from .dashboards_widgets import Widgets

API_TAGO = os.environ.get('TAGO_API') or 'https://api.tago.io'
REALTIME = os.environ.get('TAGO_REALTIME') or 'https://realtime.tago.io'


class Dashboards:
  def __init__(self, acc_token):
    self.token = acc_token
    self.default_headers = {
      'content-type': 'application/json', 'Account-Token': acc_token}

  def list(self, page=1, fields=['id', 'name'], filter={}, amount=20, orderBy='label,asc'):
    params = {
      'page': page,
      'filter': filter,
      'fields': fields,
      'amount': amount,
      'orderBy': orderBy,
    }
    return requests.get('{api_endpoint}/dashboard'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(params)).json()

    # Create a Dashboard
  def create(self, data):
    data = data if data else {}
    return requests.post('{api_endpoint}/dashboard'.format(api_endpoint=API_TAGO), headers=self.default_headers, data=json.dumps(data)).json()

    # Edit a Dashboard
  def edit(self, dashboard_id, data):
    data = data if data else {}
    return requests.put('{api_endpoint}/dashboard/{dashboard_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers, data=json.dumps(data)).json()

    # Delete a Dashboard
  def delete(self, dashboard_id):
    return requests.delete('{api_endpoint}/dashboard/{dashboard_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers).json()

    # Get Information for a Dashboard
  def info(self, dashboard_id):
    if dashboard_id is None or dashboard_id == '':
      # return None # Dashboard ID parameter is obligatory.
      raise ValueError('Dashboard ID parameter is obrigatory.')

    return requests.get('{api_endpoint}/dashboard/{dashboard_id}'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers).json()

  def duplicate(self, dashboard_id, data):
    data = data if data else {}
    if dashboard_id is None or dashboard_id == '':
      raise ValueError('Dashboard ID parameter is obrigatory.')
    return requests.post('{api_endpoint}/dashboard/{dashboard_id}/duplicate'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers, data=json.dumps(data)).json()

    # Get share list of the dashboard
  def shareList(self, dashboard_id):
    if dashboard_id is None or dashboard_id == '':
      raise ValueError('dashboard_id must be set')
    return list_share("dashboard", dashboard_id, self.default_headers)

    # Share the dashboard with another person
  def shareSendInvite(self, dashboard_id, data):
    data = data if data else {}
    if dashboard_id is None or dashboard_id == '':
      raise ValueError('dashboard_id must be set')
    elif data['email'] is None or data['email'] == '':
      raise ValueError('email must be set in data')
    return invite("dashboard", dashboard_id, data, self.default_headers)

    # Change permssions of dashboard
  def shareEdit(self, share_id, data):
    data = data if data else {}
    if share_id is None or share_id == '':
      raise ValueError('share_id must be set')
    elif data['email'] is None or data['email'] == '':
      raise ValueError('email must be set in data')
    return edit(share_id, data, self.default_headers)

    # Remove share of a dashboard
  def shareDelete(self, share_id):
    if share_id is None or share_id == '':
      raise ValueError('share_id must be set')
    return remove(share_id, self.default_headers)

    # Generate new public token for the dashboard
  def genPublicToken(self, dashboard_id):
    if dashboard_id is None or dashboard_id == '':
      raise ValueError('dashboard_id must be set')

    return requests.get('{api_endpoint}/dashboard/{dashboard_id}/share/public'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers).json()

    # Clone the dashboard with special parameters
  def shareClone(self, dashboard_id, data):
    if dashboard_id is None or dashboard_id == '':
      raise ValueError('dashboard_id must be set')
    elif data.email is None:
      raise ValueError('email must be set in data')

    return requests.post('{api_endpoint}/dashboard/{dashboard_id}/share/copy'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers).json()

  def listDevicesRelated(self, dashboard_id):
    return requests.get('{api_endpoint}/dashboard/{dashboard_id}/devices'.format(api_endpoint=API_TAGO, dashboard_id=dashboard_id), headers=self.default_headers).json()

  def getWidgets(self):
    return Widgets(self.token)



import requests
import json
import os


class Currency:
  def __init__(self, key):
    self.key = key
    self.default_headers = {
      'content-type': 'application/json', 'Device-Token': key}

    #
    # Find conversion rates for currency
    # API Documentation : https://currencylayer.com
    # c_from{string} : Currency for which conversion rate is to be found
    # c_to{string} : Currency to which c_from is to be converted
    # for multiple conversions c_to should be comma separated currencies.
    # example for single conversion : "convert('USD', 'EUR')"
    # example for multiple conversion : "convert('USD', 'EUR,GBP')"
    #

  def convert(self, c_from, c_to):
    if not c_from or not c_to:
      raise ValueError("Empty or Bad arguments")

    url = 'http://apilayer.net/api/live'
    data = {'access_key': self.key, 'source': c_from,
            'currencies': c_to, 'format': 1}
    convert_cur = requests.get(
      url, params=data, headers=self.default_headers).json()
    convert_cur_json = {
      'from': convert_cur['source'], 'result': convert_cur['quotes']}
    return convert_cur_json
